<?php

namespace SM\Controller;

use SM\Controller\SMCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use SM\Service\CdaService;
use SM\Traits\TResponse;

class CdaController extends SMCrud
{
    use TResponse;
    
    protected $CdaService;
    
    public function __construct($crudService, $environment, CdaService $CdaService)
    {
        parent::__construct($crudService, $environment);
        $this->CdaService = $CdaService;
    }
    
    public function getCda(Request $request)
    {
        try {
            $data = $this->CdaService->getCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getFuncionarios(Request $request)
    {
        try {
            $data = $this->CdaService->getFuncionarios($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getFuncionarioLogado(Request $request)
    {
        try {
            $data = $this->CdaService->getFuncionarioLogado($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getPeriodoApuraPonto(Request $request)
    {
        try {
            $data = $this->CdaService->getPeriodoApuraPonto($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getClienteCda(Request $request)
    {
        try {
            $data = $this->CdaService->getClienteCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getRepresentante(Request $request)
    {
        try {
            $data = $this->CdaService->getRepresentante($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getPropostaCda(Request $request)
    {
        try {
            $data = $this->CdaService->getPropostaCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getProjetoOperadorCliente(Request $request)
    {
        try {
            $data = $this->CdaService->getProjetoOperadorCliente($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getTipoAtividadeCda(Request $request)
    {
        try {
            $data = $this->CdaService->getTipoAtividadeCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getProspectCda(Request $request)
    {
        try {
            $data = $this->CdaService->getProspectCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getInterlocutorProspectCda(Request $request)
    {
        try {
            $data = $this->CdaService->getInterlocutorProspectCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    public function getInterlocutorClienteCda(Request $request)
    {
        try {
            $data = $this->CdaService->getInterlocutorClienteCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getLicencaUsoCda(Request $request)
    {
        try {
            $data = $this->CdaService->getLicencaUsoCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getContatoCda(Request $request)
    {
        try {
            $data = $this->CdaService->getContatoCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getJustHorasNaoFaturadasCda(Request $request)
    {
        try {
            $data = $this->CdaService->getJustHorasNaoFaturadasCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getMotivoEvoContCda(Request $request)
    {
        try {
            $data = $this->CdaService->getMotivoEvoContCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    public function getMotivoContatoCda(Request $request)
    {
        try {
            $data = $this->CdaService->getMotivoContatoCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getSistemaCda(Request $request)
    {
        try {
            $data = $this->CdaService->getSistemaCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getMotivoJustificativaCda(Request $request)
    {
        try {
            $data = $this->CdaService->getMotivoJustificativaCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    } 

    public function getMotivoAfastamentoInssCda(Request $request)
    {
        try {
            $data = $this->CdaService->getMotivoAfastamentoInssCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getServParticipantesCda(Request $request)
    {
        try {
            $data = $this->CdaService->getServParticipantesCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function consultaProxNrServPrest(Request $request)
    {
        try {
            $data = $this->CdaService->consultaProxNrServPrest($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function inserirAtividadeCda(Request $request)
    {
        try {
            $data = $this->CdaService->inserirAtividadeCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }  
}
