<?php

namespace SM\Controller;

use SM\Controller\SMCrud;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use SM\Service\Sm00049AgrupamentoDeContratosService;
use SM\Traits\TResponse;

class Sm00049AgrupamentoDeContratosController extends SMCrud
{

    use TResponse;

    protected $AgrupamentoService;

    public function __construct($crudService, $environment, Sm00049AgrupamentoDeContratosService $AgrupamentoService)
    {
        parent::__construct($crudService, $environment);
        $this->AgrupamentoService = $AgrupamentoService;
    }

    public function getInformacoesGridPrincipal()
    {
        try {
            $data = $this->AgrupamentoService->getInformacoesGridPrincipal();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getParceirosDeNegocio(Request $request)
    {
        try {
            $data = $this->AgrupamentoService->getParceirosDeNegocio($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getEscoposFaturamento()
    {
        try {
            $data = $this->AgrupamentoService->getEscoposFaturamento();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getTipoOperacao()
    {
        try {
            $data = $this->AgrupamentoService->getTipoOperacao();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getSeriesNFAgrupamento()
    {
        try {
            $data = $this->AgrupamentoService->getSeriesNFAgrupamento();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getFilialAgrupamento()
    {
        try {
            $data = $this->AgrupamentoService->getFilialAgrupamento();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getContratosAgrupamento(Request $request)
    {
        try {
            $data = $this->AgrupamentoService->getContratosAgrupamento($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getInformacoesGridContratos(Request $request)
    {
        try {
            $data = $this->AgrupamentoService->getInformacoesGridContratos($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function validarEscoposAgrupamento(Request $request, Response $response)
    {
        try {
            $possuiescsimilares = $this->AgrupamentoService->validarEscoposAgrupamento($request->getParameters());
            $response->addDataSet(new DataSet("agrupamento", array("IDESCSIMILARES" => $possuiescsimilares)));
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function salvarAgrupamento(Request $request)
    {
        try {
            $data = $this->AgrupamentoService->salvarAgrupamento($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function updateAgrupamento(Request $request)
    {
        try {
            $data = $this->AgrupamentoService->updateAgrupamento($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deletarAgrupamento(Request $request)
    {
        try {
            $data = $this->AgrupamentoService->deletarAgrupamento($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deletarContratos(Request $request)
    {
        try {
            $this->AgrupamentoService->deletarContratos($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function validarContratosAprovados(Request $request, Response $response)
    {
        try {
            $data = $this->AgrupamentoService->validarContratosAprovados($request->getParameters());
            $dtsVal = new DataSet('contratosAprovados', $data);
            $response->addDataSet($dtsVal);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function salvarContratos(Request $request)
    {
        try {
            $data = $this->AgrupamentoService->salvarContratos($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
}
