import {
    Http, IDictionary, Metadata, IEventParam,
} from '@zeedhi/core';
import {
    ApexChart, DateRange, Frame, Grid, Modal, ModalService, Text, Select,
} from '@zeedhi/common';

export class FrameBillingController {
    public filterDate: any;

    private modalFilter!: Modal;

    private modalFilterBillingScope!: Modal;

    private modalFilterContractItems!: Modal;

    public closeGrids({ component }: any) {
        this.openChartDetails(component.name.split('_')[1]);
    }

    public openChartDetails(name: string) {
        const statusExibição: boolean = Metadata.getInstance<Frame>('frame-billing').isVisible;
        Metadata.getInstance<DateRange>('range-dashboard').isVisible = !statusExibição;
        Metadata.getInstance<Frame>('frame-billing').isVisible = !statusExibição;
        Metadata.getInstance<Frame>(`frame-${name}`).isVisible = statusExibição;
    }

    public chartMounted({ component }: IEventParam<ApexChart>) {
        const options = {
            chart: {
                events: {
                    click: this.clickEvent.bind(this, component),
                },
            },
        };
        component.updateChart(options);
    }

    public clickEvent(component: any) {
        this.openChartDetails(component.name.split('_')[1]);
    }

    public async mountCharts({ component }: any, route: string, date: any, text: string, nameOfChart: string) {
        // const dateRange = Metadata.getInstance<DateRange>('range-dashboard').value;
        const dataLabels: any = [];
        const dataSeries: any = [];
        const periodText = Metadata.getInstance<Text>(text);

        if (date !== '') periodText.text = `5 Principais ${nameOfChart} | Período: ${date[0]} - ${date[1]}`;
        else periodText.text = `5 Principais ${nameOfChart} | Período: Últimos 30 dias`;

        await Http.post(route, {
            DTINICIO: (date === '' || date.length < 1) ? null : date[0],
            DTFINAL: (date === '' || date.length < 2) ? null : date[1],
        }).then((response: IDictionary) => {
            if (response.data.dataset.chart.length) {
                response.data.dataset.chart.forEach((dados: IDictionary) => {
                    dataLabels.push(dados.NMTIPOORCAMENTO || dados.NMSECUNDARIPARC || dados.NMITEMCONTRATO);
                    dataSeries.push(dados.VALOR);
                });
            } else {
                dataLabels.push('Nenhum dado disponível');
                dataSeries.push(100);
            }
        });
        const options = { series: dataSeries, labels: dataLabels };
        component.updateChart(options);
    }

    public mountChartBusinessPartner({ component }: any) {
        const chart = Metadata.getInstance<ApexChart>('chart-billing-businessPartner_VFxPN');
        const route = '/getChartBusinessPartner';
        const text = Metadata.getInstance<Text>('subtitle-businessPartner').name;
        const nameOfChart = 'Parceiros';

        const date = (component.component === 'ZdDateRange') ? component.value : '';
        this.mountCharts({ component: chart }, route, date, text, nameOfChart);
    }

    public mountChartBillingScope({ component }: any) {
        const chart = Metadata.getInstance<ApexChart>('pie-chart-billingScope_VFxEF');
        const route = '/getChartBillingScope';
        const text = Metadata.getInstance<Text>('subtitle-billingScope').name;
        const nameOfChart = 'Escopos';

        const date = (component.component === 'ZdDateRange') ? component.value : '';
        this.mountCharts({ component: chart }, route, date, text, nameOfChart);
    }

    public mountChartContractItems({ component }: any) {
        const chart = Metadata.getInstance<ApexChart>('pie-chart-contractItems_VFxIC');
        const route = '/getChartContractItems';
        const text = Metadata.getInstance<Text>('subtitle-contractItems').name;
        const nameOfChart = 'Itens';

        const date = (component.component === 'ZdDateRange') ? component.value : '';
        this.mountCharts({ component: chart }, route, date, text, nameOfChart);
    }

    public async mountChartMonthlyHistory({ component }: any) {
        const datab: any = [];

        await Http.get('/getMonthlyHistory').then((response: IDictionary) => {
            if (response.data.dataset.chart.length) {
                response.data.dataset.chart.forEach((dados: IDictionary) => {
                    datab.push({
                        name: dados.MES,
                        data: [dados.VALOR],
                    });
                    component.options.xaxis.categories.push('');
                });
            } else {
                datab.push({
                    name: 'Nenhum dado disponível',
                    data: [100],
                });
            }
            const options = { series: datab };
            component.updateChart(options);
        });
    }

    /* public onCreatedFilter({ component }: IEventParam<TekGrid>) {
      const actualDate = new Date();
      const lastDate = new Date();
      lastDate.setDate(lastDate.getDate() - 30);
  
      const formatActualDate = actualDate.toLocaleString().substr(0, 10);
      const formatLastDate = lastDate.toLocaleString().substr(0, 10);
  
      this.filterDate = [formatLastDate, formatActualDate,];
      const { datasource } = component;
        (datasource as TekRestDatasource).dynamicFilter = {
            DTINCLUSAO: [{
              relation: 'AND',
              operation: 'BETWEEN',
              value: [formatLastDate, formatActualDate],
          }],
      };
      datasource.get();
    } */

    // ------------------------Funções do frame: Frame-Billing-VFxPN ----------------------

    public async openModal() {
        this.modalFilter = await ModalService.createFromJson('/dashboard/modal/modal-filter-VFxPN', true);
        this.modalFilter.show();
    }

    public closeModal() {
        this.modalFilter.hide();
        this.modalFilter?.destroy();
    }

    public callMountGrid({ component }: any) {
        if (component.component === 'ZdButton') {
            const parc = Metadata.getInstance<Select>('select-businessPartner').value;
            const date = Metadata.getInstance<DateRange>('selectDate-modal-filter-VFxPN').value;

            this.mountGridBusinessPartner(date, parc);
            this.closeModal();
        } else {
            this.mountGridBusinessPartner('', 0);
        }
    }

    public mountGridBusinessPartner(date: any, parc: number) {
        const grid = Metadata.getInstance<Grid>('grid-businessPartner');
        grid.datasource.data = [];

        Http.post('/getBusinessPartnerDetailed', {
            DTINICIO: (date === '' || date.length < 1) ? null : date[0],
            DTFINAL: (date === '' || date.length < 2) ? null : date[1],
            NRPARCNEGOCIO: (parc === 0) ? null : parc,
        }).then((response: IDictionary) => {
            response.data.dataset.grid.forEach((element: IDictionary) => {
                grid.datasource.data.push({
                    NRPARCNEGOCIO: element.NRPARCNEGOCIO,
                    NMSECUNDARIPARC: element.NMSECUNDARIPARC,
                    VALOR: element.VALOR,
                });
            });
        });
    }

    // ------------------------Funções do frame: Frame-Billing-VFxEF ----------------------

    public async openModalBillingScope() {
        this.modalFilterBillingScope = await ModalService.createFromJson('/dashboard/modal/modal-filter-VFxEF', true);
        this.modalFilterBillingScope.show();
    }

    public closeModalBillingScope() {
        this.modalFilterBillingScope.hide();
        this.modalFilterBillingScope?.destroy();
    }

    public callMountGridBillingScope({ component }: any) {
        if (component.component === 'ZdButton') {
            const parc = Metadata.getInstance<Select>('select-billingScope').value;
            const date = Metadata.getInstance<DateRange>('selectDate-modal-filter-VFxEF').value;

            this.mountGridBillingScope(date, parc);
            this.closeModalBillingScope();
        } else {
            this.mountGridBillingScope('', 0);
        }
    }

    public mountGridBillingScope(date: any, parc: number) {
        const grid = Metadata.getInstance<Grid>('grid-VFaturadoXEFaturamento');
        grid.datasource.data = [];

        Http.post('/getBillingScopeDetailed', {
            DTINICIO: (date === '' || date.length < 1) ? null : date[0],
            DTFINAL: (date === '' || date.length < 2) ? null : date[1],
            NRTIPOORCAMENTO: (parc === 0) ? null : parc,
        }).then((response: IDictionary) => {
            response.data.dataset.grid.forEach((element: IDictionary) => {
                grid.datasource.data.push({
                    NRTIPOORCAMENTO: element.NRTIPOORCAMENTO,
                    NMTIPOORCAMENTO: element.NMTIPOORCAMENTO,
                    VALOR: element.VALOR,
                });
            });
        });
    }

    public async openModalContractItems() {
        this.modalFilterContractItems = await ModalService.createFromJson('/dashboard/modal/modal-filter-VFxIC', true);
        this.modalFilterContractItems.show();
    }

    public closeModalContractItems() {
        this.modalFilterContractItems.hide();
        this.modalFilterContractItems?.destroy();
    }

    public callMountGridContractItems({ component }: any) {
        if (component.component === 'ZdButton') {
            const parc = Metadata.getInstance<Select>('select-contractItems').value;
            const date = Metadata.getInstance<DateRange>('selectDate-modal-filter-VFxIC').value;

            this.mountGridContractItems(date, parc);
            this.closeModalContractItems();
        } else {
            this.mountGridContractItems('', 0);
        }
    }

    public mountGridContractItems(date: any, parc: number) {
        const grid = Metadata.getInstance<Grid>('grid-VFaturadoXIContrato');
        grid.datasource.data = [];

        Http.post('/getContractItemsDetailed', {
            DTINICIO: (date === '' || date.length < 1) ? null : date[0],
            DTFINAL: (date === '' || date.length < 2) ? null : date[1],
            CDSERVORCA: (parc === 0) ? null : parc,
        }).then((response: IDictionary) => {
            response.data.dataset.grid.forEach((element: IDictionary) => {
                grid.datasource.data.push({
                    CDSERVORCA: element.CDSERVORCA,
                    NMITEMCONTRATO: element.NMITEMCONTRATO,
                    VALOR: element.VALOR,
                });
            });
        });
    }
}
