import { TekGrid } from '@zeedhi/teknisa-components-common';
import { Metadata, Http, IEventParam } from '@zeedhi/core';
import {
    LoadingService, TextInput, Select, Tabs, Form, DialogService, Button,
} from '@zeedhi/common';
import { Utilities } from '@/util/Utilities';

export class Sm00006000TipoDeMedidaController {
    public tekgridVisivel: boolean = true;

    public currentRow: any = {};

    public viewTab: boolean = false;

    get textFrame() {
        return this.currentRow.DSTPMEDIDASERV;
    }

    get formVisivel() {
        return !this.tekgridVisivel;
    }

    get tabInvisivel() {
        return this.currentRow.IDTPMEDIDASERV !== 'F';
    }

    public addNewRow() {
        const grid = Metadata.getInstance<TekGrid>('tab-variacao');
        grid.addNewRow({ NRVARIACAOTPMEDIDA: 0, CDTPMEDIDASERV: this.currentRow.CDTPMEDIDASERV }, 'start');
    }

    public afterModify() {
        Metadata.getInstance<TekGrid>('tab-variacao').datasource.get();
    }

    public abrirFrameAdd() {
        this.tekgridVisivel = false;
        const tabs = Metadata.getInstance<Tabs>('tabsInformation');
        tabs.activeTab = 0;
        this.currentRow = {};
        Metadata.getInstance<TextInput>('CDTPMEDIDASERV').value = null;
        Metadata.getInstance<TextInput>('DSTPMEDIDASERV').value = null;
        Metadata.getInstance<Select>('IDTPMEDIDASERV').setValue(null);
    }

    public abrirFrame({ row }: any) {
        this.tekgridVisivel = false;
        this.currentRow = row;
        const tabs = Metadata.getInstance<Tabs>('tabsInformation');
        tabs.activeTab = 0;
        this.carregarDadosAbaTipoMedida();
    }

    public verificaTab() {
        const tabs = Metadata.getInstance<Tabs>('tabsInformation');
        const tabAtiva = tabs.activeTab;

        if (tabs.tabs[tabAtiva].name === 'tab_variacao') {
            this.carregarDadosAbaVariacao();
        }
    }

    public voltarTekGrid() {
        this.tekgridVisivel = true;
    }

    public carregarDadosAbaVariacao() {
        const cdtpmedidaserv = this.currentRow.CDTPMEDIDASERV;
        try {
            const grid = Metadata.getInstance<TekGrid>('tab-variacao');
            grid.datasource.setFilter({
                CDTPMEDIDASERV: cdtpmedidaserv,
            });
        } catch (e) {
            // console.log(e);
        }
    }

    public carregarDadosAbaTipoMedida() {
        Metadata.getInstance<TextInput>('DSTPMEDIDASERV').value = this.currentRow.DSTPMEDIDASERV;
        Metadata.getInstance<Select>('IDTPMEDIDASERV').setValue(this.currentRow.IDTPMEDIDASERV);
        Metadata.getInstance<Select>('CDTPMEDIDASERV').value = this.currentRow.CDTPMEDIDASERV;
    }

    public saveTabTipoMedida({ event }: IEventParam<Button>) {
        event!.preventDefault();
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid');
        const form = Metadata.getInstance<Form>('formTabTipoMedida');

        if (Utilities.validateForm(form)) {
            LoadingService.show();
            const codigo = Metadata.getInstance<TextInput>('CDTPMEDIDASERV').value;
            const descricao = Metadata.getInstance<TextInput>('DSTPMEDIDASERV').value;
            const tipo = Metadata.getInstance<Select>('IDTPMEDIDASERV').value;
            Http.post('/saveTabTipoMedida', {
                CDTPMEDIDASERV: codigo,
                DSTPMEDIDASERV: descricao,
                IDTPMEDIDASERV: tipo,
            }).then(() => {
                this.currentRow.IDTPMEDIDASERV = tipo;
                if (!codigo) {
                    this.tekgridVisivel = true;
                }
                grid.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public insertVariacaoTipoMedida({ event }: any) {
        event!.preventDefault();
        const grid = Metadata.getInstance<TekGrid>('tab-variacao');
        const editedrows = grid.getEditedRows();

        let gridInvalido = true;
        gridInvalido = editedrows.some((row) => row.CDTPMEDIDAVARIAVEL == null || row.QTMEDIDAINIVARIACAO == null || row.QTMEDIDAFIMVARIACAO == null || row.VRPERCVARIACAO == null);

        if (!gridInvalido) {
            LoadingService.show();
            Http.post('/insertVariacaoTipoMedida', editedrows)
                .then(async () => {
                    grid.cancelEditedRows();
                    Utilities.showSuccessMessage();
                    grid.datasource.get();
                }).catch((error) => {
                    if (error.response.data.error === 'EXISTE') {
                        Utilities.showDialogMessage('error', 'Operação Bloqueada!', 'Já existe uma variação cadastrada para o "Tipo de Medida para Variação" e para o intervalo de "Quantidade da Medida" informados.');
                    } else {
                        Utilities.showErrorMessage(error);
                    }
                }).finally(() => {
                    LoadingService.hide();
                });
        } else {
            Utilities.alertMessage('Existem campos obrigatórios não preenchidos!', 'error');
        }
    }

    showDialogWithButtonsGrid({ event }: any) {
        event.preventDefault();

        DialogService.show({
            name: 'dialog-deletar-tipo-medida',
            type: 'warning',
            title: 'Excluir Registro',
            text: 'Deseja realmente excluir todos os registros selecionados?',
            buttons: [
                {
                    name: 'NAO',
                    component: 'ZdButton',
                    label: 'Não',
                    outline: true,
                    events: {
                        click: () => {
                            DialogService.hide();
                        },
                    },
                },
                {
                    name: 'SIM',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            this.deleteTipoMedida();
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    public deleteTipoMedida() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid');
        LoadingService.show();
        Http.post('/deleteTipoMedida', grid.selectedRows)
            .then(() => {
                grid.selectedRows = [];
                grid.cancelEditedRows();
                grid.reload();
                Utilities.showSuccessMessage();
            }).catch((error) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
    }

    public showDialogWithButtons({ event }: any) {
        event.preventDefault();

        DialogService.show({
            name: 'dialog-deletar-variacao',
            type: 'warning',
            title: 'Excluir Registro',
            text: 'Deseja realmente excluir todos os registros selecionados?',
            buttons: [
                {
                    name: 'NAO',
                    component: 'ZdButton',
                    label: 'Não',
                    outline: true,
                    events: {
                        click: () => {
                            DialogService.hide();
                        },
                    },
                },
                {
                    name: 'SIM',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            this.deleteVariacaoTipoMedida();
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    public deleteVariacaoTipoMedida() {
        const grid = Metadata.getInstance<TekGrid>('tab-variacao');
        LoadingService.show();
        Http.post('/deleteVariacaoTipoMedida', grid.selectedRows)
            .then(() => {
                grid.selectedRows = [];
                grid.cancelEditedRows();
                grid.reload();
                Utilities.showSuccessMessage();
            }).catch((error) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
    }
}
